#
# spec file for package python-parse_type
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without python2
Name:           python-parse_type
Version:        0.6.3
Release:        2.2
Summary:        Extension to the parse module
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jenisys/parse_type
Source:         https://github.com/jenisys/parse_type/archive/v%{version}.tar.gz
# to remove python 2 is the goal of 0.7.0
# https://github.com/jenisys/parse_type/blob/main/CHANGES.txt
# https://github.com/jenisys/parse_type/pull/24
Patch0:         python-parse_type-remove-python2.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-parse >= 1.12.0
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-enum34
%endif
%ifpython2
Requires:       python-enum34
%endif
# SECTION test requirements
BuildRequires:  %{python_module parse >= 1.12.0}
BuildRequires:  %{python_module pytest >= 3.0}
# /SECTION
%python_subpackages

%description
parse_type extends the parse module (opposite of string.format()) with
the following features:

  * build type converters for common use cases (enum/mapping, choice)
  * build a type converter with a cardinality constraint (0..1, 0..*, 1..*)
    from the type converter with cardinality=1.
  * compose a type converter from other type converters
  * an extended parser that supports the CardinalityField naming schema
    and creates missing type variants (0..1, 0..*, 1..*) from the
    primary type converter

%prep
%autosetup -p1 -n parse_type-%{version}

# no extra pytest options are needed
rm pytest.ini
# Remove bundled parse.py
rm parse_type/parse.py
sed -i 's:from parse_type import parse:import parse:' \
  tests/*.py tests/parse_tests_with_parse_type/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/parse_type
%{python_sitelib}/parse_type-%{version}*-info

%changelog
* Thu Sep 26 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Thu Aug 29 2024 pgajdos@suse.com
- version update to 0.6.3
  * Copy structured test suite to "tests/parse_tests/"
  * Copy structured test suite to "tests/parse_tests_with_parse_type"
  * REMOVE: tests/test_parse.py
  * README: Fix compact display of BADGES (was using multi-line)
  * CI: Add support for Python 3.12
- added patches
  fix https://github.com/jenisys/parse_type/pull/24
  + python-parse_type-remove-python2.patch
* Sun Dec 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.2:
  * #21: tests/test_parse.py tests ``parse_type.parse`` (per
    default).
  * REASON: Using for older installed ``parse`` module may
    cause weird problems.
  * RELATED TO: ``parse v1.19.1`` (behavior changed compared to
    ``v1.19.0``)
* Sun Jul  2 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.6.1:
  - Switch to MIT license (same as: parse module)
  - Use SPDX-License-Identifier in source code (to simplify
    understanding)
  - UPDATE/SYNC to parse v1.19.1
  - ADDED: pyproject.toml to support newer pip versions
  - REASON: setup.py becomes DEPRECATED in 2023-09 for newer pip
    versions.
  - Issue #19: 0.6.0: pytest is failing in two units (caused by:
    parse v1.19.1)
  - Issue #1: Licensing confusion
* Mon Feb 28 2022 pgajdos@suse.com
- version update to 0.6.0
  + issue #17: setup.py: Remove use of "use_2to3"
  + parse issue #119 (same as: #121): int_convert memory effect with number-base discovery
  + UPDATE to parse v1.18.0 (needed by: parse issue #119)
  + parse PR #122: Fixes issue #121 in parse: int_convert memory effect.
  + parse v1.17.0
* Wed Sep 23 2020 Ondřej Súkup <mimi.vx@gmail.com>
-  python-enum34 is mandatory with pyhon2
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.3:
  * no changelog
- Remove not needed testsuite-fix.patch
* Tue Aug 27 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.5.2
  * requires parse >= 1.12.0
  * test fixes
- shortened patch testsuite-fix.patch
* Thu Feb 14 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Wed Feb 13 2019 Matěj Cepl <mcepl@suse.com>
- Add python3-fixes.patch to make tests pass.
* Wed Nov 28 2018 Mathias Homann <Mathias.Homann@opensuse.org>
- initial package using py2pack and version 0.4.2
